<?php
namespace Elementor;

/**
 * If This File Is Called Directly, Abort.
 */
if(!defined('ABSPATH')){
	exit;
}

/**
 * Class Essential Pricing Plan Switcher for Elementor.
 */
class EPPS_Widget extends Widget_Base{

	// Function For Get The Slug Of The Element Name.
	public function get_name(){
		return 'essential-pricing-plan-switcher-for-elementor';
	}

	// Function For Get The Name Of The Element.
	public function get_title(){
		return esc_html__('Essential Pricing Plan', EPPS_DOMAIN);
	}

	// Function For Get The Icon Of The Element.
	public function get_icon(){
		return 'eicon-column';
	}

	// Function For Include Element Into The Category.
	public function get_categories(){
		return ['essential-pricing-plan-switcher-for-elementor'];
	}

	// Function For Include Element Keywords.
	public function get_keywords(){
		return ['epps', 'essential pricing plan switcher'];
	}

	// Function For Include CSS.
	public function get_style_depends(){
		return ['epps-style'];
	}

	// Adding The Controls Fields For The Essential Pricing Plan Switcher for Elementor.
	protected function register_controls(){

		// Start General Section.
		$this->start_controls_section(
			'epps_section_general',array(
				'label'         	=> esc_html__('General', EPPS_DOMAIN),
			)
		);

		// Select Layout Design.
		$this->add_control(
			'epps_design', [
				'label'         	=> esc_html__('Layouts', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::SELECT,
				'options' 			=> [
					'design-1'  	=> esc_html__('Design 1', EPPS_DOMAIN),
					'design-2'  	=> esc_html__('Design 2', EPPS_DOMAIN),
					'design-3'  	=> esc_html__('Design 3', EPPS_DOMAIN),
					'design-4'  	=> esc_html__('Design 4', EPPS_DOMAIN),
					'design-5'  	=> esc_html__('Design 5', EPPS_DOMAIN),
				],
				'default'       	=> 'design-1',
			]
		);

		// Select Plan Number.
		$this->add_control(
			'epps_plan_count', [
				'label'         	=> esc_html__('Plans', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::NUMBER,
				'default'       	=> 3,
				'min'           	=> 1,
				'max'           	=> 4,
			]
		);

		// Plan Grid Number.
		$this->add_responsive_control(
			'epps_grid_columns', [
				'label'         	=> esc_html__('Grid Columns', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::SELECT,
				'default'       	=> '3',
				'tablet_default' 	=> '2',
				'mobile_default' 	=> '1',
				'options' 			=> [
					'1' 			=> '1',
					'2' 			=> '2',
					'3' 			=> '3',
					'4' 			=> '4',
				],
				'prefix_class'      => 'elementor-grid%s-',
				'frontend_available'=> true,
				'selectors'         => [
					'.elementor-msie {{WRAPPER}} .elementor-product-item' => 'width: calc( 100% / {{SIZE}} )',
				]
			]
		);

		// Plan Switcher.
		$this->add_control(
			'epps_plan_switcher', [
				'label' 			=> esc_html__('Plan Switcher', EPPS_DOMAIN),
				'type' 				=> Controls_Manager::SWITCHER,
				'label_on' 			=> esc_html__('Show', EPPS_DOMAIN),
				'label_off' 		=> esc_html__('Hide', EPPS_DOMAIN),
				'return_value' 		=> 'yes',
				'default' 			=> 'yes',
			]
		);

		// Switcher 1.
		$this->add_control(
			'epps_plan_switcher1', [
				'label'         	=> esc_html__('Switcher 1', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::TEXT,
				'default'       	=> esc_html__('MONTHLY', EPPS_DOMAIN),
				'condition'     	=> [
					'epps_plan_switcher' => 'yes',
				],
			]
		);

		// Switcher 2.
		$this->add_control(
			'epps_plan_switcher2', [
				'label'         	=> esc_html__('Switcher 2', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::TEXT,
				'default'       	=> esc_html__('YEARLY', EPPS_DOMAIN),
				'condition'     	=> [
					'epps_plan_switcher' => 'yes',
				],
			]
		);

		//Static Currency Symbol.
        $this->add_control(
            'epps_currency_symbol', [
                'label'             => esc_html__('Currency Symbol', EPPS_DOMAIN),
                'type'              => Controls_Manager::SELECT,
                'options'           => [
                    ''              => esc_html__('None', EPPS_DOMAIN ),
                    'dollar'        => '&#36; ' . _x('Dollar', 'Currency', EPPS_DOMAIN),
                    'euro'          => '&#128; ' . _x('Euro', 'Currency', EPPS_DOMAIN),
                    'baht'          => '&#3647; ' . _x('Baht', 'Currency', EPPS_DOMAIN),
                    'franc'         => '&#8355; ' . _x('Franc', 'Currency', EPPS_DOMAIN),
                    'guilder'       => '&fnof; ' . _x('Guilder', 'Currency', EPPS_DOMAIN),
                    'krona'         => 'kr ' . _x('Krona', 'Currency', EPPS_DOMAIN),
                    'lira'          => '&#8356; ' . _x('Lira', 'Currency', EPPS_DOMAIN),
                    'peseta'        => '&#8359 ' . _x('Peseta', 'Currency', EPPS_DOMAIN),
                    'peso'          => '&#8369; ' . _x('Peso', 'Currency', EPPS_DOMAIN),
                    'pound'         => '&#163; ' . _x('Pound Sterling', 'Currency', EPPS_DOMAIN),
                    'real'          => 'R$ ' . _x('Real', 'Currency', EPPS_DOMAIN),
                    'ruble'         => '&#8381; ' . _x('Ruble', 'Currency', EPPS_DOMAIN),
                    'rupee'         => '&#8360; ' . _x('Rupee', 'Currency', EPPS_DOMAIN),
                    'indian_rupee'  => '&#8377; ' . _x('Rupee (Indian)', 'Currency', EPPS_DOMAIN),
                    'shekel'        => '&#8362; ' . _x('Shekel', 'Currency', EPPS_DOMAIN),
                    'yen'           => '&#165; ' . _x('Yen/Yuan', 'Currency', EPPS_DOMAIN),
                    'won'           => '&#8361; ' . _x('Won', 'Currency', EPPS_DOMAIN),
                    'epps_custom' => esc_html__('Custom', EPPS_DOMAIN),
                ],
                'default'           => 'dollar',
            ]
        );

		//Static Currency Text.
        $this->add_control(
            'epps_currency_text_symbol', [
                'label'             => esc_html__('Custom Symbol', EPPS_DOMAIN),
                'type'              => Controls_Manager::TEXT,
                'condition'         => [
                    'epps_currency_symbol' => 'epps_custom',
                ],
            ]
        );

		//Button Position.
        $this->add_control(
            'epps_btn_position', [
                'label'         	=> esc_html__('Button Position', EPPS_DOMAIN),
                'type'          	=> Controls_Manager::SELECT,
                'options'       	=> [
                    'above_feature'   => esc_html__('Above Feature', EPPS_DOMAIN),
					'under_feature'   => esc_html__('Under Feature', EPPS_DOMAIN),
                ],
                'default'       	=> 'under_feature',
            ]
        );

		// Column Gap.
		$this->add_responsive_control(
			'epps_plan_column_gap', [
				'label'         	=> esc_html__('Column Gap', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::SLIDER,
				'default'       	=> [
					'size'      	=> 20,
				],
				'range'         	=> [
					'px'        	=> [
						'min'   	=> 0,
						'max'   	=> 100,
					],
				],
				'frontend_available' => true,
				'selectors'     	=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-plan-list' => 'grid-column-gap: {{SIZE}}{{UNIT}};',
				],
			]
		);

		// Row Gap.
		$this->add_responsive_control(
			'epps_plan_row_gap', [
				'label'         	=> esc_html__('Row Gap', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::SLIDER,
				'default'       	=> [
					'size'      	=> 20,
				],
				'range'         	=> [
					'px'        	=> [
						'min'   	=> 0,
						'max'   	=> 100,
					],
				],
				'frontend_available' => true,
				'selectors'     	=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-plan-list' => 'grid-row-gap: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();
		// End Heading Section.

		// Satrt Plans sections.
		$this->add_plan();
		// End Plans sections.

        //Start Custom Item Section.
        $this->start_controls_section(
            'woofoo_custom_item_section', array(
                'label'             => esc_html__('Label', EPPS_DOMAIN),
            )
        );

		// Select Label Design.
		$this->add_control(
			'epps_label_design', [
				'label'         	=> esc_html__('Label', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::SELECT,
				'options' 			=> [
					'epps-label-1'  	=> esc_html__('Label 1', EPPS_DOMAIN),
					'epps-label-2'  	=> esc_html__('Label 2', EPPS_DOMAIN),
					'epps-label-3'  	=> esc_html__('Label 3', EPPS_DOMAIN),
					'epps-label-4'  	=> esc_html__('Label 4', EPPS_DOMAIN),
					'epps-label-5'  	=> esc_html__('Label 5', EPPS_DOMAIN),
				],
				'default' 	      	=> 'epps-label-1',
			]
		);

		// Select Label Position.
		$this->add_control(
			'epps_label_position', [
				'label'         	=> esc_html__('Select Label Position', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::SELECT,
				'options' 			=> [
					'ltr'  			=> esc_html__('LTR', EPPS_DOMAIN),
					'rtl'  			=> esc_html__('RTL', EPPS_DOMAIN),
				],
				'default' 	      	=> 'rtl',
				'condition'			=> [
					'epps_design!'	=> ['design-3'],
				],
			]
		);

		// Switcher Spacing.
		$this->add_responsive_control(
			'epps_label_spacing', [
				'label' 			=> esc_html__('Label Spacing', EPPS_DOMAIN),
				'type' 				=> Controls_Manager::SLIDER,
				'size_units' 		=> ['px'],
				'range' 			=> [
					'px' 			=> [
						'min' 		=> 0,
						'max' 		=> 200,
						'step' 		=> 1,
					],
				],
				'default' 			=> [
					'unit' 			=> 'px',
					'size' 			=> 0,
				],
				'selectors' => [
					'{{WRAPPER}} .epps-plan-label' => 'top: {{SIZE}}{{UNIT}};',
				],
				'condition'			=> [
					'epps_design!'	=> ['design-3'],
					'epps_label_design!' => ['epps-label-3'],
				],
			]
		);

		$this->end_controls_section();
        //End Grid Options Section.

		// Start Switcher Style Tab.
		$this->start_controls_section(
			'epps_switcher_style', [
				'label'         	=> esc_html__('Switcher', EPPS_DOMAIN),
				'tab'           	=> Controls_Manager::TAB_STYLE,
			]
		);

		// Alignment.
		$this->add_responsive_control(
			'epps_plan_switcher_align', [
				'label'     		=> esc_html__('Alignment', EPPS_DOMAIN),
				'type'      		=> Controls_Manager::CHOOSE,
				'options'   		=> [
					'left' 			=> [
						'title' 	=> esc_html__('Left', EPPS_DOMAIN),
						'icon'  	=> 'eicon-text-align-left',
					],
					'center' 		=> [
						'title' 	=> esc_html__('Center', EPPS_DOMAIN),
						'icon'  	=> 'eicon-text-align-center',
					],
					'right' 		=> [
						'title' 	=> esc_html__('Right', EPPS_DOMAIN),
						'icon'  	=> 'eicon-text-align-right',
					],
				],
				'default'   		=> 'center',
				'selectors' 		=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-plan-switcher' => 'justify-content: {{VALUE}};',
				],
			]
		);

		// Switcher Spacing.
		$this->add_responsive_control(
			'epps_switcher_spacing', [
				'label' 			=> esc_html__('Switcher Spacing', EPPS_DOMAIN),
				'type' 				=> Controls_Manager::SLIDER,
				'size_units' 		=> ['px', '%'],
				'range' 			=> [
					'px' 			=> [
						'min' 		=> 0,
						'max' 		=> 100,
						'step' 		=> 1,
					],
					'%' 			=> [
						'min' 		=> 0,
						'max' 		=> 100,
					],
				],
				'default' 			=> [
					'unit' 			=> 'px',
					'size' 			=> 30,
				],
				'selectors' => [
					'{{WRAPPER}} .epps-main-wrapper .epps-plan-switcher' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);

		// Switcher Typography.
		$this->add_group_control(
			Group_Control_Typography::get_type(), [
				'name'          	=> 'epps_switcher_text_typography',
				'label'         	=> esc_html__('Switcher Typography', EPPS_DOMAIN),
				'selector'      	=> '{{WRAPPER}} .epps-main-wrapper .epps-switcher-text',
			]
		);

		// Switcher Text Color.
		$this->add_control(
			'epps_switcher_text_color', [
				'label'         	=> esc_html__('Switcher Text Color', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::COLOR,
				'selectors'     	=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-switcher-text' => 'color: {{VALUE}};',
				],
			]
		);

		// Switch Color.
		$this->add_control(
			'epps_switcher_switch_color', [
				'label'         	=> esc_html__('Switch Color', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::COLOR,
				'default'       	=> '#ffffff',
				'selectors'     	=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-slider:before' => 'background-color: {{VALUE}};',
				],
			]
		);

		// Switch Enable Background Color.
		$this->add_group_control(
            Group_Control_Background::get_type(), [
                'name'          	=> 'epps_eneble_switch_color',
				'selector'     		=> '{{WRAPPER}} .epps-main-wrapper input:checked + .epps-slider',
                'types'         	=> ['classic', 'gradient'],
				'exclude'           => ['image'],
				'fields_options'    => [
                    'background'    => [
                        'label'     => esc_html__(' Switch Enable Background Color', EPPS_DOMAIN),
                    ],
                ],
            ]
        );

		// Switch Disable Background Color.
		$this->add_group_control(
            Group_Control_Background::get_type(), [
                'name'          	=> 'epps_disable_switch_color',
				'selector'     		=> '{{WRAPPER}} .epps-main-wrapper .epps-slider',
                'types'         	=> ['classic', 'gradient'],
				'exclude'           => ['image'],
				'fields_options'    => [
                    'background'    => [
                        'label'     => esc_html__(' Switch Disable Background Color', EPPS_DOMAIN),
                    ],
                ],
            ]
        );

		// Icon Spacing.
		$this->add_responsive_control(
			'epps_switch_radius', [
				'label' 			=> esc_html__('Switch Border Radius', EPPS_DOMAIN),
				'type' 				=> Controls_Manager::SLIDER,
				'size_units' 		=> ['px', '%' ],
				'range' 			=> [
					'px' 			=> [
						'min' 		=> 0,
						'max' 		=> 100,
						'step' 		=> 1,
					],
					'%' 			=> [
						'min' 		=> 0,
						'max' 		=> 100,
					],
				],
				'default' 			=> [
					'unit' 			=> '%',
					'size' 			=> 50,
				],
				'selectors' 		=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-slider.epps-round:before' => 'border-radius: {{SIZE}}{{UNIT}};',
				],
			]
		);

		// Icon Spacing.
		$this->add_responsive_control(
			'epps_switcher_radius', [
				'label' 			=> esc_html__('Switcher Border Radius', EPPS_DOMAIN),
				'type' 				=> Controls_Manager::SLIDER,
				'size_units' 		=> ['px', '%' ],
				'range' 			=> [
					'px' 			=> [
						'min' 		=> 0,
						'max' 		=> 100,
						'step' 		=> 1,
					],
					'%' 			=> [
						'min' 		=> 0,
						'max' 		=> 100,
					],
				],
				'default' 			=> [
					'unit' 			=> 'px',
					'size' 			=> 34,
				],
				'selectors' 		=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-slider.epps-round' => 'border-radius: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();
		// End Switcher Style Tab.

		// Start Plans Style Tab.
		$this->start_controls_section(
			'epps_plan_card', [
				'label'         	=> esc_html__('Plan Card', EPPS_DOMAIN),
				'tab'           	=> Controls_Manager::TAB_STYLE,
			]
		);

		// Plan Color Tab.
		$this->start_controls_tabs(
			'epps_plan_color_tabs'
		);

		// Start Plan Color Normal Tab.
		$this->start_controls_tab(
			'epps_plan_color_normal_tab', [
				'label'         	=> esc_html__('Normal', EPPS_DOMAIN),
			]
		);

		// Plan Gradient Background.
		$this->add_group_control(
            Group_Control_Background::get_type(), [
                'name'          	=> 'epps_column_background_color',
                'types'        		=> ['classic', 'gradient'],
                'selector'      	=> '{{WRAPPER}} .epps-main-wrapper .epps-plan-list .epps-plan',
				'fields_options'    => [
					'background'    => [
						'label'     => esc_html__('Background Color', EPPS_DOMAIN),
					],
				],
            ]
        );

		// Title Gradient Background.
		$this->add_group_control(
            Group_Control_Background::get_type(), [
                'name'          	=> 'epps_title_background_color',
				'selector'     		=> '{{WRAPPER}} .epps-design-1 .epps-title-price-wrapper,
				{{WRAPPER}} .epps-design-2 .epps-heading-wrapper,
				{{WRAPPER}} .epps-design-3 .epps-heading-wrapper,
				{{WRAPPER}} .epps-design-3 .epps-heading-wrapper:before,
				{{WRAPPER}} .epps-design-4 .epps-title-price-wrapper,
				{{WRAPPER}} .epps-design-5 .epps-heading-wrapper',
                'types'         	=> ['classic', 'gradient'],
				'fields_options'    => [
                    'background'    => [
                        'label'     => esc_html__(' Title Background Color', EPPS_DOMAIN),
                    ],
                ],
            ]
        );

		// Plan Box Shadow.
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(), [
				'name'          	=> 'epps_plan_card_box_shadow',
				'selector'     		=> '{{WRAPPER}} .epps-main-wrapper .epps-plan-list .epps-plan',
				'separator'    		=> 'before',
			]
		);

		$this->end_controls_tab();
		// End Plan Color Normal Tab.

		// Start Plan Color Hover Tab.
		$this->start_controls_tab(
			'epps_plan_hover_tab', [
				'label'         	=> esc_html__('Hover', EPPS_DOMAIN),
			]
		);

		// Plan Gradient Background Hover.
		$this->add_group_control(
			Group_Control_Background::get_type(),[
				'name' 	        	=> 'epps_column_bg_hover_color',
				'selector'     		=> '{{WRAPPER}} .epps-main-wrapper .epps-plan-list .epps-plan:hover',
				'types'         	=> ['classic', 'gradient'],
				'fields_options'    => [
					'background'    => [
						'label'     => esc_html__('Background Color', EPPS_DOMAIN),
					],
				],
			]
		);

		// Title Gradient Background Hover.
		$this->add_group_control(
			Group_Control_Background::get_type(),[
				'name'          	=> 'epps_title_bg_hover_color',
				'selector'     		=> '{{WRAPPER}} .epps-design-1 .epps-plan:hover .epps-title-price-wrapper,
				{{WRAPPER}} .epps-design-2 .epps-plan:hover .epps-heading-wrapper,
				{{WRAPPER}} .epps-design-3 .epps-plan:hover .epps-heading-wrapper,
				{{WRAPPER}} .epps-design-3 .epps-plan:hover .epps-heading-wrapper:before,
				{{WRAPPER}} .epps-design-4 .epps-plan:hover .epps-title-price-wrapper,
				{{WRAPPER}} .epps-design-5 .epps-plan:hover .epps-heading-wrapper',
				'types'         	=> ['classic', 'gradient'],
				'fields_options'    => [
					'background'    => [
						'label'     => esc_html__('Title Background Color', EPPS_DOMAIN),
					],
				],
			]
		);

		// Column Hover Border Color.
		$this->add_control(
			'epps_column_border_hover', [
				'label'         	=> esc_html__('Border Color', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::COLOR,
				'separator'    		=> 'after',
				'selectors'     	=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-plan-list .epps-plan:hover' => 'border-color: {{VALUE}};',
				],
			]
		);

		// Plan Box Shadow.
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(), [
				'name'          	=> 'epps_plan_card_shadow_hover',
				'selector'     		=> '{{WRAPPER}} .epps-main-wrapper .epps-plan-list .epps-plan:hover',
				'separator'    		=> 'before',
			]
		);

		$this->end_controls_tab();
		// End Plan Color hover Tab.

		$this->end_controls_tabs();
		// End Plan Color Tab.

		// Plan Plan.
		$this->add_control(
			'epps_plan_bg', [
				'label'        		=> esc_html__('Plan', EPPS_DOMAIN),
				'type'         		=> Controls_Manager::HEADING,
			]
		);

		// Plan Border.
		$this->add_group_control(
			Group_Control_Border::get_type(), [
				'name'          	=> 'epps_plan_card_border',
				'label_block'   	=> true,
				'selector'      	=> '{{WRAPPER}} .epps-main-wrapper .epps-plan-list .epps-plan',
			]
		);

		// Plan Border Radius.
		$this->add_responsive_control(
			'epps_plan_card_border_radius', [
				'label'         	=> esc_html__('Border Radius', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::DIMENSIONS,
				'size_units'    	=> ['px', '%'],
				'selectors'     	=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-plan-list .epps-plan,
					{{WRAPPER}} .epps-design-3 .epps-label' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		// Plan Padding.
		$this->add_responsive_control(
			'epps_plan_card_padding', [
				'label'         	=> esc_html__('Padding', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::DIMENSIONS,
				'size_units'    	=> ['px', '%'],
				'selectors'     	=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-design-1 .epps-content,
					{{WRAPPER}} .epps-main-wrapper .epps-design-2 .epps-content,
					{{WRAPPER}} .epps-main-wrapper .epps-design-3 .epps-content,
					{{WRAPPER}} .epps-main-wrapper .epps-design-4 .epps-content,
					{{WRAPPER}} .epps-main-wrapper .epps-design-5 .epps-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		// Plan Title.
		$this->add_control(
			'epps_plan_title_bg', [
				'label'        		=> esc_html__('Title', EPPS_DOMAIN),
				'type'         		=> Controls_Manager::HEADING,
			]
		);

		// Title Padding.
		$this->add_responsive_control(
			'epps_title_padding', [
				'label'         	=> esc_html__('Title Padding', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::DIMENSIONS,
				'size_units'    	=> ['px', '%'],
				'selectors'     	=> [
					'{{WRAPPER}} .epps-design-1 .epps-title-price-wrapper,
					{{WRAPPER}} .epps-main-wrapper .epps-design-2 .epps-heading-wrapper,
					{{WRAPPER}} .epps-design-3 .epps-heading-wrapper,
					{{WRAPPER}} .epps-design-4 .epps-title-price-wrapper,
					{{WRAPPER}} .epps-design-5 .epps-heading-wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		// Title Background Overlay.
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' 				=> 'epps_background_overlay',
				'selector' 			=> '{{WRAPPER}} .epps-design-1 .epps-title-price-wrapper:after,
				{{WRAPPER}} .epps-design-2 .epps-heading-wrapper:after,
				{{WRAPPER}} .epps-design-3 .epps-heading-wrapper:after,
				{{WRAPPER}} .epps-design-4 .epps-title-price-wrapper:after,
				{{WRAPPER}} .epps-design-5 .epps-heading-wrapper:after',
				'types'         	=> ['classic', 'gradient'],
				'exclude'           => ['image'],
				'fields_options' 	=> [
					'background' 	=> [
						'label'     => esc_html__('Title Background Overlay', EPPS_DOMAIN),
						
					],
				],
			]
		);

		// Title Background Overlay Opacity.
		$this->add_responsive_control(
			'epps_background_overlay_opacity',
			[
				'label' => esc_html__( 'Opacity', EPPS_DOMAIN ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => .5,
				],
				'range' => [
					'px' => [
						'max' => 1,
						'step' => 0.01,
					],
				],
				'selectors' => [
					'{{WRAPPER}}  .epps-design-1 .epps-title-price-wrapper:after,
					{{WRAPPER}} .epps-design-2 .epps-heading-wrapper:after,
					{{WRAPPER}} .epps-design-3 .epps-heading-wrapper:after,
					{{WRAPPER}} .epps-design-4 .epps-title-price-wrapper:after,
					{{WRAPPER}} .epps-design-5 .epps-heading-wrapper:after' => 'opacity: {{SIZE}};',
				],
				'condition' => [
					'epps_background_overlay_background' => [ 'classic', 'gradient' ],
				],
			]
		);

		// Title Background Height.
		$this->add_responsive_control(
			'epps_title_bg_height', [
				'label' 			=> esc_html__('Title Background Height', EPPS_DOMAIN),
				'type' 				=> Controls_Manager::SLIDER,
				'size_units' 		=> ['px', '%'],
				'range'				=> [
					'px' 			=> [
						'min' 		=> 0,
						'max' 		=> 300,
						'step' 		=> 1,
					],
					'%' 			=> [
						'min' 		=> 0,
						'max' 		=> 100,
					],
				],
				'selectors' 		=> [
					'{{WRAPPER}} .epps-design-4 .epps-title-price-wrapper,
					{{WRAPPER}} .epps-design-5 .epps-heading-wrapper' => 'height: {{SIZE}}{{UNIT}};',
				],
				'condition'			=> [
					'epps_design' 	=> ['design-4', 'design-5'],
				],
			]
		);

		$this->end_controls_section();
		// End General Style Tab.

		// Start Plans Style Tab.
		$this->start_controls_section(
			'epps_plan_style', [
				'label'         	=> esc_html__('Plan', EPPS_DOMAIN),
				'tab'           	=> Controls_Manager::TAB_STYLE,
			]
		);

		// Plan Title.
		$this->add_control(
			'epps_plan_title', [
				'label'        		=> esc_html__('Title', EPPS_DOMAIN),
				'type'         		=> Controls_Manager::HEADING,
			]
		);

		// Alignment.
		$this->add_responsive_control(
			'epps_title_align', [
				'label'    			=> esc_html__('Title Alignment', EPPS_DOMAIN),
				'type'     			=> Controls_Manager::CHOOSE,
				'options'  			=> [
					'left' 			=> [
						'title' 	=> esc_html__('Left', EPPS_DOMAIN),
						'icon'  	=> 'eicon-text-align-left',
					],
					'center'		=> [
						'title' 	=> esc_html__('Center', EPPS_DOMAIN),
						'icon'  	=> 'eicon-text-align-center',
					],
					'right' 		=> [
						'title' 	=> esc_html__('Right', EPPS_DOMAIN),
						'icon'  	=> 'eicon-text-align-right',
					],
				],
				'default'   		=> 'center',
				'selectors' 		=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-heading-wrapper' => 'text-align: {{VALUE}};',
				],
				'condition'			=> [
					'epps_design'	=> ['design-1', 'design-2', 'design-4', 'design-5'],
				],
			]
		);

		// Title Typography.
		$this->add_group_control(
			Group_Control_Typography::get_type(), [
				'name'         	 	=> 'epps_plan_title_typography',
				'selector'     	 	=> '{{WRAPPER}} .epps-main-wrapper .epps-plan-heading',
			]
		);

		// Title Color.
		$this->add_control(
			'epps_plan_title_color', [
				'label'         	=> esc_html__('Color', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::COLOR,
				'selectors'     	=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-plan-heading' => 'color: {{VALUE}};',
				],
			]
		);

		// Title Spacing.
		$this->add_responsive_control(
			'epps_title_spacing', [
				'label' 			=> esc_html__('Title Spacing', EPPS_DOMAIN),
				'type' 				=> Controls_Manager::SLIDER,
				'size_units' 		=> ['px', '%'],
				'range'				=> [
					'px' 			=> [
						'min' 		=> 0,
						'max' 		=> 300,
						'step' 		=> 1,
					],
					'%' 			=> [
						'min' 		=> 0,
						'max' 		=> 100,
					],
				],
				'default' 			=> [
					'unit' 			=> 'px',
					'size' 			=> 10,
				],
				'selectors' 		=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-prices-wrapper' => 'margin-top: {{SIZE}}{{UNIT}};',
				],
				'condition'			=> [
					'epps_design' 	=> ['design-1', 'design-4'],
				],
			]
		);

		// Plan Price.
		$this->add_control(
			'epps_plan_price', [
				'label'        		=> esc_html__('Price', EPPS_DOMAIN),
				'type'         		=> Controls_Manager::HEADING,
				'separator'    		=> 'before',
			]
		);

		// Alignment.
		$this->add_responsive_control(
			'epps_price_align', [
				'label'    			=> esc_html__('Price Alignment', EPPS_DOMAIN),
				'type'     			=> Controls_Manager::CHOOSE,
				'options'  			=> [
					'left' 			=> [
						'title' 	=> esc_html__('Left', EPPS_DOMAIN),
						'icon'  	=> 'eicon-text-align-left',
					],
					'center'		=> [
						'title' 	=> esc_html__('Center', EPPS_DOMAIN),
						'icon'  	=> 'eicon-text-align-center',
					],
					'right' 		=> [
						'title' 	=> esc_html__('Right', EPPS_DOMAIN),
						'icon'  	=> 'eicon-text-align-right',
					],
				],
				'default'   		=> 'center',
				'selectors' 		=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-prices-wrapper' => 'justify-content: {{VALUE}};',
				],
			]
		);

		// Price Typography.
		$this->add_group_control(
			Group_Control_Typography::get_type(), [
				'name'          	=> 'epps_plan_price_typography',
				'selector'      	=> '{{WRAPPER}} .epps-main-wrapper .epps-normal-price',
			]
		);

		// Price Color.
		$this->add_control(
			'epps_plan_price_color', [
				'label'         	=> esc_html__('Color', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::COLOR,
				'selectors'     	=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-normal-price' => 'color: {{VALUE}};',
				],
			]
		);

		// Title Spacing.
		$this->add_responsive_control(
			'epps_price_spacing', [
				'label' 			=> esc_html__('Price Spacing', EPPS_DOMAIN),
				'type' 				=> Controls_Manager::SLIDER,
				'size_units' 		=> ['px', '%'],
				'range'				=> [
					'px' 			=> [
						'min' 		=> 0,
						'max' 		=> 300,
						'step' 		=> 1,
					],
					'%' 			=> [
						'min' 		=> 0,
						'max' 		=> 100,
					],
				],
				'default' 			=> [
					'unit' 			=> 'px',
					'size' 			=> 10,
				],
				'selectors' 		=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-prices-wrapper' => 'margin-top: {{SIZE}}{{UNIT}};',
				],
				'condition'			=> [
					'epps_design' 	=> ['design-5'],
				],
			]
		);

		// Price Line.
		$this->add_control(
			'epps_price_line_through', [
				'label'    			=> esc_html__('Price Line Through', EPPS_DOMAIN),
				'type' 				=> Controls_Manager::SWITCHER,
				'label_on' 			=> esc_html__('Show', EPPS_DOMAIN),
				'label_off' 		=> esc_html__('Hide', EPPS_DOMAIN),
				'return_value' 		=> 'yes',
				'default' 			=> 'no',
			]
		);

		// Price Color.
		$this->add_control(
			'epps_price_line_through_color', [
				'label'         	=> esc_html__('Price Line Through', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::COLOR,
				'selectors'     	=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-price-line p' => 'text-decoration-color: {{VALUE}};',
				],
				'condition'			=> [
					'epps_price_line_through' 	=> 'yes',
				],
			]
		);

		// Title Spacing.
		$this->add_responsive_control(
			'epps_line_width', [
				'label' 			=> esc_html__('Price Line Through Width', EPPS_DOMAIN),
				'type' 				=> Controls_Manager::SLIDER,
				'size_units' 		=> ['px'],
				'range'				=> [
					'px' 			=> [
						'min' 		=> 0,
						'max' 		=> 10,
						'step' 		=> 1,
					],
				],
				'default' 			=> [
					'unit' 			=> 'px',
					'size' 			=> 1,
				],
				'selectors' 		=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-price-line p' => 'text-decoration-thickness: {{SIZE}}{{UNIT}};',
				],
				'condition'			=> [
					'epps_price_line_through' 	=> 'yes',
				],
			]
		);

		// Plan Sale Price.
		$this->add_control(
			'epps_plan_sale_price', [
				'label'        		=> esc_html__('Sale Price', EPPS_DOMAIN),
				'type'         		=> Controls_Manager::HEADING,
				'separator'    		=> 'before',
			]
		);

		// Sale Price Typography.
		$this->add_group_control(
			Group_Control_Typography::get_type(), [
				'name'          	=> 'epps_plan_sale_price_typography',
				'selector'      	=> '{{WRAPPER}} .epps-main-wrapper .epps-sale-price',
			]
		);

		// Sale Price Color.
		$this->add_control(
			'epps_plan_sale_price_color', [
				'label'         	=> esc_html__('Color', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::COLOR,
				'selectors'     	=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-sale-price' => 'color: {{VALUE}};',
				],
			]
		);

		// Plan Description.
		$this->add_control(
			'epps_plan_description', [
				'label'        		=> esc_html__('Description', EPPS_DOMAIN),
				'type'         		=> Controls_Manager::HEADING,
				'separator'    		=> 'before',
			]
		);

		// Description Spacing.
		$this->add_responsive_control(
			'epps_description_spacing', [
				'label' 			=> esc_html__('Description Spacing', EPPS_DOMAIN),
				'type' 				=> Controls_Manager::SLIDER,
				'size_units' 		=> ['px', '%'],
				'range'				=> [
					'px' 			=> [
						'min' 		=> 0,
						'max' 		=> 300,
						'step' 		=> 1,
					],
					'%' 			=> [
						'min' 		=> 0,
						'max' 		=> 100,
					],
				],
				'default' 			=> [
					'unit' 			=> 'px',
					'size' 			=> 10,
				],
				'selectors' 		=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-description-wrapper' => 'margin-top: {{SIZE}}{{UNIT}}; margin-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);

		// Description Alignment.
		$this->add_responsive_control(
			'epps_description_align', [
				'label'    			=> esc_html__('Description Alignment', EPPS_DOMAIN),
				'type'     			=> Controls_Manager::CHOOSE,
				'options'  			=> [
					'left' 			=> [
						'title' 	=> esc_html__('Left', EPPS_DOMAIN),
						'icon'  	=> 'eicon-text-align-left',
					],
					'center'		=> [
						'title' 	=> esc_html__('Center', EPPS_DOMAIN),
						'icon'  	=> 'eicon-text-align-center',
					],
					'right' 		=> [
						'title' 	=> esc_html__('Right', EPPS_DOMAIN),
						'icon'  	=> 'eicon-text-align-right',
					],
				],
				'default'   		=> 'center',
				'selectors' 		=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-plan-list .epps-description-wrapper' => 'text-align: {{VALUE}};',
				],
			]
		);

		// Description Typography.
		$this->add_group_control(
			Group_Control_Typography::get_type(), [
				'name'          	=> 'epps_plan_description_typography',
				'selector'      	=> '{{WRAPPER}} .epps-main-wrapper .epps-plan-description',
			]
		);

		// Description Color.
		$this->add_control(
			'epps_plan_description_color', [
				'label'         	=> esc_html__('Color', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::COLOR,
				'selectors'     	=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-plan-description' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();
		// End Plans Style Tab.

		// Start Features Style Tab.
		$this->start_controls_section(
			'epps_features_style', [
				'label'         	=> esc_html__('Features', EPPS_DOMAIN),
				'tab'         		=> Controls_Manager::TAB_STYLE,
			]
		);

		// Features Title.
		$this->add_control(
			'epps_plan_features_title', [
				'label'        		=> esc_html__('Features Title', EPPS_DOMAIN),
				'type'         		=> Controls_Manager::HEADING,
			]
		);

		// Features Title Alignment.
		$this->add_responsive_control(
			'epps_feature_title_align', [
				'label'    			=> esc_html__('Features Title Alignment', EPPS_DOMAIN),
				'type'     			=> Controls_Manager::CHOOSE,
				'options'  			=> [
					'left' 			=> [
						'title' 	=> esc_html__('Left', EPPS_DOMAIN),
						'icon'  	=> 'eicon-text-align-left',
					],
					'center'		=> [
						'title' 	=> esc_html__('Center', EPPS_DOMAIN),
						'icon'  	=> 'eicon-text-align-center',
					],
					'right' 		=> [
						'title' 	=> esc_html__('Right', EPPS_DOMAIN),
						'icon'  	=> 'eicon-text-align-right',
					],
				],
				'default'   		=> 'center',
				'selectors' 		=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-plan-list .epps-features-title-wrapper' => 'text-align: {{VALUE}};',
				],
			]
		);

		// Feature Title Spacing.
		$this->add_responsive_control(
			'epps_feature_title_spacing', [
				'label' 			=> esc_html__('Title Spacing', EPPS_DOMAIN),
				'type' 				=> Controls_Manager::SLIDER,
				'size_units' 		=> ['px', '%'],
				'range'				=> [
					'px' 			=> [
						'min' 		=> 0,
						'max' 		=> 100,
						'step' 		=> 1,
					],
					'%' 			=> [
						'min' 		=> 0,
						'max' 		=> 100,
					],
				],
				'default' 			=> [
					'unit' 			=> 'px',
					'size' 			=> 10,
				],
				'selectors' 		=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-features-title-wrapper' => 'margin-top: {{SIZE}}{{UNIT}}; margin-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);

		// Features Title Typography.
		$this->add_group_control(
			Group_Control_Typography::get_type(), [
				'name'          	=> 'epps_plan_features_title_typography',
				'selector'      	=> '{{WRAPPER}} .epps-main-wrapper .epps-plan-features-title',
			]
		);

		// Features Title Color.
		$this->add_control(
			'epps_plan_features_title_color', [
				'label'         	=> esc_html__('Color', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::COLOR,
				'selectors'     	=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-plan-features-title' => 'color: {{VALUE}};',
				],
			]
		);

		// Features Icon.
		$this->add_control(
			'epps_plan_features_icon', [
				'label'        		=> esc_html__('Features Icon', EPPS_DOMAIN),
				'type'         		=> Controls_Manager::HEADING,
				'separator'    		=> 'before',
			]
		);

		// Icon Size.
		$this->add_responsive_control(
			'epps_plan_features_icon_size', [
				'label'         	=> esc_html__('Icon Size', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::SLIDER,
				'range'         	=> [
					'px'        	=> [
						'min'   	=> 0,
						'max'   	=> 100,
					],
				],
				'default'       	=> ['size'  => 15],
				'selectors'     	=> [
					'{{WRAPPER}} .epps-main-wrapper .epps_feature_icon' => 'font-size: {{SIZE}}{{UNIT}};',
				],
			]
		);

		// Icon Spacing.
		$this->add_responsive_control(
			'epps_icon_spacing', [
				'label' 			=> esc_html__('Icon Spacing', EPPS_DOMAIN),
				'type' 				=> Controls_Manager::SLIDER,
				'size_units' 		=> ['px', '%' ],
				'range' 			=> [
					'px' 			=> [
						'min' 		=> 0,
						'max' 		=> 100,
						'step' 		=> 1,
					],
					'%' 			=> [
						'min' 		=> 0,
						'max' 		=> 100,
					],
				],
				'default' 			=> [
					'unit' 			=> 'px',
					'size' 			=> 3,
				],
				'selectors' 		=> [
					'{{WRAPPER}} .epps-main-wrapper .epps_feature_icon' => 'margin-right: {{SIZE}}{{UNIT}};',
				],
			]
		);

		// Include Color.
		$this->add_control(
			'epps_plan_features_icon_include_color', [
				'label'         	=> esc_html__('Include Color', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::COLOR,
				'selectors'     	=> [
					'{{WRAPPER}} .epps-main-wrapper .epps_feature_icon.epps-icon-include' => 'color: {{VALUE}};',
				],
			]
		);

		// Exclude Color.
		$this->add_control(
			'epps_plan_features_icon_exclude_color', [
				'label'         	=> esc_html__('Exclude Color', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::COLOR,
				'selectors'     	=> [
					'{{WRAPPER}} .epps-main-wrapper .epps_feature_icon.epps-icon-exclude' => 'color: {{VALUE}};',
				],
			]
		);

		// Plan Features List.
		$this->add_control(
			'epps_plan_features', [
				'label'        		=> esc_html__('Features List', EPPS_DOMAIN),
				'type'         		=> Controls_Manager::HEADING,
				'separator'    		=> 'before',
			]
		);

		// Features List Alignment.
		$this->add_responsive_control(
			'epps_feature_list_align', [
				'label'    			=> esc_html__('Features List Alignment', EPPS_DOMAIN),
				'type'     			=> Controls_Manager::CHOOSE,
				'options'  			=> [
					'left' 			=> [
						'title' 	=> esc_html__('Left', EPPS_DOMAIN),
						'icon'  	=> 'eicon-text-align-left',
					],
					'center'		=> [
						'title' 	=> esc_html__('Center', EPPS_DOMAIN),
						'icon'  	=> 'eicon-text-align-center',
					],
					'right' 		=> [
						'title' 	=> esc_html__('Right', EPPS_DOMAIN),
						'icon'  	=> 'eicon-text-align-right',
					],
				],
				'default'   		=> 'center',
				'selectors' 		=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-plan-list .epps-features-wrapper' => 'text-align: {{VALUE}};',
				],
			]
		);

		// Features List Typography.
		$this->add_group_control(
			Group_Control_Typography::get_type(), [
				'name'          	=> 'epps_plan_features_typography',
				'selector'      	=> '{{WRAPPER}} .epps-main-wrapper .epps-feature-text',
			]
		);

		// Features Include List Color.
		$this->add_control(
			'epps_features_include_color', [
				'label'         	=> esc_html__('Include List Color', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::COLOR,
				'selectors'     	=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-feature-text.epps-icon-include' => 'color: {{VALUE}};',
				],
			]
		);

		// Features Exclude List Color.
		$this->add_control(
			'epps_features_exclude_color', [
				'label'         	=> esc_html__('Exclude List Color', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::COLOR,
				'selectors'     	=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-feature-text.epps-icon-exclude' => 'color: {{VALUE}};',
				],
			]
		);

		// Divider Width.
		$this->add_responsive_control(
			'epps_divider_width', [
				'label' 			=> esc_html__('Divider Width', EPPS_DOMAIN),
				'type' 				=> Controls_Manager::SLIDER,
				'size_units' 		=> 'px',
				'range' 			=> [
					'px' 			=> [
						'min' 		=> 0,
						'max' 		=> 10,
						'step'		=> 1,
					],
				],
				'selectors' 		=> [
					'{{WRAPPER}} .epps-main-wrapper li.epps-features-item' => 'border-bottom-width: {{SIZE}}{{UNIT}};',
				],
			]
		);

		// Divider Color.
		$this->add_control(
			'epps_divider_color', [
				'label'         	=> esc_html__('Divider Color', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::COLOR,
				'selectors'     	=> [
					'{{WRAPPER}} .epps-main-wrapper li.epps-features-item' => 'border-color: {{VALUE}};',
				],
			]
		);

		// List Spacing.
		$this->add_responsive_control(
			'epps_list_spacing', [
				'label' 			=> esc_html__('List Spacing', EPPS_DOMAIN),
				'type' 				=> Controls_Manager::SLIDER,
				'size_units' 		=> ['px', '%'],
				'range' 			=> [
					'px' 			=> [
						'min' 		=> 0,
						'max' 		=> 100,
						'step' 		=> 1,
					],
					'%' 			=> [
						'min' 		=> 0,
						'max' 		=> 100,
					],
				],
				'default' 			=> [
					'unit' 			=> 'px',
					'size' 			=> 5,
				],
				'selectors' 		=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-features-item' => 'padding-top: {{SIZE}}{{UNIT}}; padding-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();
		// End Features Style Tab.

		// Start Button Style Tab.
		$this->start_controls_section(
			'epps_button_style', [
				'label'         	=> esc_html__('Button', EPPS_DOMAIN),
				'tab'           	=> Controls_Manager::TAB_STYLE,
			]
		);

		// Button Alignment.
		$this->add_responsive_control(
			'epps_button_align', [
				'label'    			=> esc_html__('Button Alignment', EPPS_DOMAIN),
				'type'     			=> Controls_Manager::CHOOSE,
				'options'  			=> [
					'left' 			=> [
						'title' 	=> esc_html__('Left', EPPS_DOMAIN),
						'icon'  	=> 'eicon-text-align-left',
					],
					'center'		=> [
						'title' 	=> esc_html__('Center', EPPS_DOMAIN),
						'icon'  	=> 'eicon-text-align-center',
					],
					'right' 		=> [
						'title' 	=> esc_html__('Right', EPPS_DOMAIN),
						'icon'  	=> 'eicon-text-align-right',
					],
				],
				'default'   		=> 'center',
				'selectors' 		=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-plan-list .epps-btn-wrapper' => 'text-align: {{VALUE}};',
				],
			]
		);

		// Button Typography.
		$this->add_group_control(
			Group_Control_Typography::get_type(), [
				'name'          	=> 'epps_btn_text_typography',
				'selector'      	=> '{{WRAPPER}} .epps-main-wrapper .epps-plan-btn',
			]
		);

		// Button Tab.
		$this->start_controls_tabs(
			'epps_button_style_tabs'
		);

		// Start Button Normal Tab.
		$this->start_controls_tab(
			'epps_button_style_normal_tab', [
				'label'         	=> esc_html__('Normal', EPPS_DOMAIN),
			]
		);

		// Button Text color.
		$this->add_control(
			'epps_button_color', [
				'label'         	=> esc_html__('Text Color', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::COLOR,
				'selectors'     	=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-plan-btn' => 'color: {{VALUE}};',
				],
			]
		);

		// Button Background color.
		$this->add_group_control(
            Group_Control_Background::get_type(),[
                'name'         		=> 'epps_btn_background_color',
				'selector'     		=> '{{WRAPPER}} .epps-main-wrapper .epps-plan-btn,
				{{WRAPPER}} .epps-design-3 .epps-plan-btn::before',
                'types'         	=> ['classic', 'gradient'],
				'exclude'           => ['image'],
                'fields_options'    => [
                    'background'    => [
                        'label'     => esc_html__('Background Color', EPPS_DOMAIN),
                    ],
                ],
            ]
        );

		$this->end_controls_tab();
		// End Button Normal Tab.

		// Start Button Hover Tab.
		$this->start_controls_tab(
			'epps_button_style_hover_tab', [
				'label'         	=> esc_html__('Hover', EPPS_DOMAIN),
			]
		);

		// Button Hover Text Color.
		$this->add_control(
			'epps_button_color_hover', [
				'label'         	=> esc_html__('Text Color', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::COLOR,
				'selectors'     	=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-plan-btn:hover' => 'color: {{VALUE}};',
				],
			]
		);

		// Button Hover Background Color.
		$this->add_group_control(
            Group_Control_Background::get_type(),[
                'name'          	=> 'epps_btn_background_color_hover',
				'selector'     		=> '{{WRAPPER}} .epps-main-wrapper .epps-plan-btn:hover,
				{{WRAPPER}} .epps-design-3 .epps-plan-btn:hover:before',
                'types'         	=> ['classic', 'gradient'],
				'exclude'           => ['image'],
                'fields_options'    => [
                    'background'    => [
                        'label'     => esc_html__('Background Color', EPPS_DOMAIN),
                    ],
                ],
            ]
        );

		// End Button Hover Border Color.
		$this->add_control(
			'epps_btn_border_color_hover', [
				'label'         	=> esc_html__('Border Color', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::COLOR,
				'separator'    		=> 'after',
				'selectors'     	=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-plan-btn:hover' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();
		// End Button hover Tab.

		$this->end_controls_tabs();
		// End Button Tab.

		// Button Border.
		$this->add_group_control(
			Group_Control_Border::get_type(), [
				'name'          	=> 'epps_btn_border',
				'label'         	=> esc_html__('Border', EPPS_DOMAIN),
				'selector'      	=> '{{WRAPPER}} .epps-main-wrapper .epps-plan-btn',
			]
		);

		// Button Border Radius.
		$this->add_control(
			'epps_btn_border_radius', [
				'label'         	=> esc_html__('Border Radius', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::DIMENSIONS,
				'size_units'    	=> ['px', '%'],
				'selectors'     	=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-plan-btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		// Button Box Shadow.
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(), [
				'name'          	=> 'epps_button_shadow',
				'selector'      	=> '{{WRAPPER}} .epps-main-wrapper .epps-plan-btn',
			]
		);

		// Button Padding.
		$this->add_responsive_control(
			'epps_button_padding', [
				'label'         	=> esc_html__('Padding', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::DIMENSIONS,
				'size_units'    	=> [ 'px', 'em', '%' ],
				'selectors'     	=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-plan-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		// Button Margin.
		$this->add_responsive_control(
			'epps_btn-margin', [
				'label'         	=> esc_html__('Margin', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::DIMENSIONS,
				'size_units'    	=> ['px', '%'],
				'selectors'     	=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-plan-btn' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();
		// End Button Style Tab.

		// Start Label Style Tab.
		$this->start_controls_section(
			'section_label_style', [
				'label'         	=> esc_html__('Label', EPPS_DOMAIN),
				'tab'         		=> Controls_Manager::TAB_STYLE,
			]
		);

		// Label Typography.
		$this->add_group_control(
			Group_Control_Typography::get_type(), [
				'name'          	=> 'epps_plan_label_typography',
				'selector'      	=> '{{WRAPPER}} .epps-main-wrapper .epps-plan-label',
			]
		);

		// Label Color.
		$this->add_control(
			'epps_plan_label_color', [
				'label'         	=> esc_html__('Color', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::COLOR,
				'selectors'     	=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-plan-label' => 'color: {{VALUE}};',
				],
			]
		);

		// Label Background Color.
		$this->add_control(
			'epps_plan_label_bg_color', [
				'label'         	=> esc_html__('Background Color', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::COLOR,
				'selectors'     	=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-plan-label' => 'background-color: {{VALUE}};',
				],
			]
		);

		// Plan Border Radius.
		$this->add_responsive_control(
			'epps_label_border_radius', [
				'label'         	=> esc_html__('Border Radius', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::DIMENSIONS,
				'size_units'    	=> ['px', '%'],
				'selectors'     	=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-plan-label' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'condition'			=> [
					'epps_label_design'	=> 'epps-label-5',
				],
			]
		);

		// Label Padding.
		$this->add_responsive_control(
			'epps_label_padding', [
				'label'         	=> esc_html__('Padding', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::DIMENSIONS,
				'size_units'    	=> ['px', '%'],
				'selectors'     	=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-plan-label' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		// Label Box Shadow.
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(), [
				'name'          	=> 'epps_label_box_shadow',
				'selector'     		=> '{{WRAPPER}} .epps-main-wrapper .epps-plan-label',
			]
		);

		// Label Spacing.
		$this->add_responsive_control(
			'epps_lable_margin', [
				'label' 			=> esc_html__('Label Spacing', EPPS_DOMAIN),
				'type' 				=> Controls_Manager::SLIDER,
				'size_units' 		=> ['px'],
				'range' 			=> [
					'px' 			=> [
						'min' 		=> 0,
						'max' 		=> 100,
						'step' 		=> 1,
					],
				],
				'default' 			=> [
					'unit' 			=> 'px',
					'size' 			=> 10,
				],
				'selectors' 		=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-plan-label' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
				'condition'			=> [
					'epps_design'	=> 'design-3',
				],
			]
		);

		// Alignment.
		$this->add_responsive_control(
			'epps_label_align', [
				'label'    			=> esc_html__('Title Alignment', EPPS_DOMAIN),
				'type'     			=> Controls_Manager::CHOOSE,
				'options'  			=> [
					'left' 			=> [
						'title' 	=> esc_html__('Left', EPPS_DOMAIN),
						'icon'  	=> 'eicon-text-align-left',
					],
					'center'		=> [
						'title' 	=> esc_html__('Center', EPPS_DOMAIN),
						'icon'  	=> 'eicon-text-align-center',
					],
					'right' 		=> [
						'title' 	=> esc_html__('Right', EPPS_DOMAIN),
						'icon'  	=> 'eicon-text-align-right',
					],
				],
				'default'   		=> 'center',
				'selectors' 		=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-label' => 'text-align: {{VALUE}};',
				],
				'condition'			=> [
					'epps_design'	=> 'design-3',
				],
			]
		);

		$this->end_controls_section();
		// End Label Style Tab.

		// Start Highlight Style Tab.
		$this->start_controls_section(
			'section_highlight_style', [
				'label'         	=> esc_html__('Highlight', EPPS_DOMAIN),
				'tab'         		=> Controls_Manager::TAB_STYLE,
			]
		);

		// Highlight Tab.
		$this->start_controls_tabs(
			'epps_highlight_style_tabs'
		);

		// Start Highlight Normal Tab.
		$this->start_controls_tab(
			'epps_highlight_style_normal_tab', [
				'label'         	=> esc_html__('Normal', EPPS_DOMAIN),
			]
		);

		// Plan Gradient Background.
		$this->add_group_control(
            Group_Control_Background::get_type(), [
                'name'          	=> 'epps_highlight_background_color',
                'types'        		=> ['classic', 'gradient'],
                'selector'      	=> '{{WRAPPER}} .epps-main-wrapper .epps-plan-list .epps-plan.epps-highlight-plan',
				'fields_options'    => [
					'background'    => [
						'label'     => esc_html__('Background Color', EPPS_DOMAIN),
					],
				],
            ]
        );

		// Title Gradient Background.
		$this->add_group_control(
            Group_Control_Background::get_type(), [
                'name'          	=> 'epps_title_highlight_background_color',
				'selector'     		=> '{{WRAPPER}} .epps-design-1 .epps-plan.epps-highlight-plan .epps-title-price-wrapper,
				{{WRAPPER}} .epps-design-2 .epps-plan.epps-highlight-plan .epps-heading-wrapper,
				{{WRAPPER}} .epps-design-3 .epps-plan.epps-highlight-plan .epps-heading-wrapper,
				{{WRAPPER}} .epps-design-3 .epps-plan.epps-highlight-plan .epps-heading-wrapper:before,
				{{WRAPPER}} .epps-design-4 .epps-plan.epps-highlight-plan .epps-title-price-wrapper,
				{{WRAPPER}} .epps-design-5 .epps-plan.epps-highlight-plan .epps-heading-wrapper',
                'types'         	=> ['classic', 'gradient'],
				'fields_options'    => [
                    'background'    => [
                        'label'     => esc_html__(' Title Background Color', EPPS_DOMAIN),
                    ],
                ],
            ]
        );

		// Plan Box Shadow.
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(), [
				'name'          	=> 'epps_highlight_box_shadow',
				'selector'     		=> '{{WRAPPER}} .epps-main-wrapper .epps-plan-list .epps-plan.epps-highlight-plan',
				'separator'    		=> 'before',
			]
		);

		// Column Border Color.
		$this->add_control(
			'epps_highlight_border', [
				'label'         	=> esc_html__('Border Color', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::COLOR,
				'separator'    		=> 'after',
				'selectors'     	=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-plan-list .epps-plan.epps-highlight-plan' => 'border-color: {{VALUE}};',
				],
			]
		);

		// Button Title.
		$this->add_control(
			'epps_btn_highlight_title', [
				'label'        		=> esc_html__('Button', EPPS_DOMAIN),
				'type'         		=> Controls_Manager::HEADING,
			]
		);

		// Button Text color.
		$this->add_control(
			'epps_highlight_button_color', [
				'label'         	=> esc_html__('Text Color', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::COLOR,
				'selectors'     	=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-plan.epps-highlight-plan .epps-plan-btn' => 'color: {{VALUE}};',
				],
			]
		);

		// Button Background color.
		$this->add_group_control(
            Group_Control_Background::get_type(),[
                'name'         		=> 'epps_highlight_btn_bg_color',
				'selector'     		=> '{{WRAPPER}} .epps-main-wrapper .epps-plan.epps-highlight-plan .epps-plan-btn,
				{{WRAPPER}} .epps-design-3 .epps-plan.epps-highlight-plan .epps-plan-btn::before',
                'types'         	=> ['classic', 'gradient'],
				'exclude'           => ['image'],
                'fields_options'    => [
                    'background'    => [
                        'label'     => esc_html__('Background Color', EPPS_DOMAIN),
                    ],
                ],
            ]
        );

		// End Button Border Color.
		$this->add_control(
			'epps_btn_highlight_border', [
				'label'         	=> esc_html__('Border Color', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::COLOR,
				'separator'    		=> 'after',
				'selectors'     	=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-plan.epps-highlight-plan .epps-plan-btn' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();
		// End Highlight Normal Tab.

		// Start Highlight Hover Tab.
		$this->start_controls_tab(
			'epps_highlight_style_hover_tab', [
				'label'         	=> esc_html__('Hover', EPPS_DOMAIN),
			]
		);

		// Plan Gradient Background.
		$this->add_group_control(
            Group_Control_Background::get_type(), [
                'name'          	=> 'epps_highlight_bg_hover_color',
                'types'        		=> ['classic', 'gradient'],
                'selector'      	=> '{{WRAPPER}} .epps-main-wrapper .epps-plan-list .epps-plan.epps-highlight-plan:hover',
				'fields_options'    => [
					'background'    => [
						'label'     => esc_html__('Background Color', EPPS_DOMAIN),
					],
				],
            ]
        );

		// Title Gradient Background.
		$this->add_group_control(
            Group_Control_Background::get_type(), [
                'name'          	=> 'epps_title_highlight_bg_hover_color',
				'selector'     		=> '{{WRAPPER}} .epps-design-1 .epps-plan.epps-highlight-plan:hover .epps-title-price-wrapper,
				{{WRAPPER}} .epps-design-2 .epps-plan.epps-highlight-plan:hover .epps-heading-wrapper,
				{{WRAPPER}} .epps-design-3 .epps-plan.epps-highlight-plan:hover .epps-heading-wrapper,
				{{WRAPPER}} .epps-design-3 .epps-plan.epps-highlight-plan:hover .epps-heading-wrapper:before,
				{{WRAPPER}} .epps-design-4 .epps-plan.epps-highlight-plan:hover .epps-title-price-wrapper,
				{{WRAPPER}} .epps-design-5 .epps-plan.epps-highlight-plan:hover .epps-heading-wrapper',
                'types'         	=> ['classic', 'gradient'],
				'fields_options'    => [
                    'background'    => [
                        'label'     => esc_html__(' Title Background Color', EPPS_DOMAIN),
                    ],
                ],
            ]
        );

		// Plan Box Shadow.
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(), [
				'name'          	=> 'epps_highlight_hover_box_shadow',
				'selector'     		=> '{{WRAPPER}} .epps-main-wrapper .epps-plan-list .epps-plan.epps-highlight-plan:hover',
				'separator'    		=> 'before',
			]
		);

		// Column Border Color.
		$this->add_control(
			'epps_highlight_border_hover', [
				'label'         	=> esc_html__('Border Color', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::COLOR,
				'separator'    		=> 'after',
				'selectors'     	=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-plan-list .epps-plan.epps-highlight-plan:hover' => 'border-color: {{VALUE}};',
				],
			]
		);

		// Button Title.
		$this->add_control(
			'epps_btn_highlight_title_hover', [
				'label'        		=> esc_html__('Button', EPPS_DOMAIN),
				'type'         		=> Controls_Manager::HEADING,
			]
		);

		// Button Text color.
		$this->add_control(
			'epps_highlight_button_color_hover', [
				'label'         	=> esc_html__('Text Color', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::COLOR,
				'selectors'     	=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-plan.epps-highlight-plan .epps-plan-btn:hover' => 'color: {{VALUE}};',
				],
			]
		);

		// Button Background color.
		$this->add_group_control(
            Group_Control_Background::get_type(),[
                'name'         		=> 'epps_highlight_btn_bg_color_hover',
				'selector'     		=> '{{WRAPPER}} .epps-main-wrapper .epps-plan.epps-highlight-plan .epps-plan-btn:hover,
				{{WRAPPER}} .epps-design-3 .epps-plan.epps-highlight-plan.epps-plan-btn:hover:before',
                'types'         	=> ['classic', 'gradient'],
				'exclude'           => ['image'],
                'fields_options'    => [
                    'background'    => [
                        'label'     => esc_html__('Background Color', EPPS_DOMAIN),
                    ],
                ],
            ]
        );

		// End Button Hover Border Color.
		$this->add_control(
			'epps_btn_highlight_border_hover', [
				'label'         	=> esc_html__('Border Color', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::COLOR,
				'separator'    		=> 'after',
				'selectors'     	=> [
					'{{WRAPPER}} .epps-main-wrapper .epps-plan.epps-highlight-plan .epps-plan-btn:hover' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();
		// End Highlight hover Tab.

		$this->end_controls_tabs();
		// End Highlight Tab.

		// Title Background Overlay.
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' 				=> 'epps_bg_hl_overlay',
				'selector' 			=> '{{WRAPPER}} .epps-design-1 .epps-plan.epps-highlight-plan  .epps-title-price-wrapper:after,
				{{WRAPPER}} .epps-design-2 .epps-plan.epps-highlight-plan  .epps-heading-wrapper:after,
				{{WRAPPER}} .epps-design-3 .epps-plan.epps-highlight-plan  .epps-heading-wrapper:after,
				{{WRAPPER}} .epps-design-4 .epps-plan.epps-highlight-plan  .epps-title-price-wrapper:after,
				{{WRAPPER}} .epps-design-5 .epps-plan.epps-highlight-plan  .epps-heading-wrapper:after',
				'types'         	=> ['classic', 'gradient'],
				'exclude'           => ['image'],
				'fields_options' 	=> [
					'background' 	=> [
						'label'     => esc_html__('Title Background Overlay', EPPS_DOMAIN),
						
					],
				],
			]
		);

		// Title Background Overlay Opacity.
		$this->add_responsive_control(
			'epps_bg_hl_overlay_opacity',
			[
				'label' => esc_html__( 'Opacity', EPPS_DOMAIN ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => .5,
				],
				'range' => [
					'px' => [
						'max' => 1,
						'step' => 0.01,
					],
				],
				'selectors' => [
					'{{WRAPPER}}  .epps-design-1 .epps-plan.epps-highlight-plan  .epps-title-price-wrapper:after,
					{{WRAPPER}} .epps-design-2 .epps-plan.epps-highlight-plan  .epps-heading-wrapper:after,
					{{WRAPPER}} .epps-design-3 .epps-plan.epps-highlight-plan  .epps-heading-wrapper:after,
					{{WRAPPER}} .epps-design-4 .epps-plan.epps-highlight-plan  .epps-title-price-wrapper:after,
					{{WRAPPER}} .epps-design-5 .epps-plan.epps-highlight-plan  .epps-heading-wrapper:after' => 'opacity: {{SIZE}};',
				],
				'condition' => [
					'epps_bg_hl_overlay_background' => [ 'classic', 'gradient' ],
				],
			]
		);

		$this->end_controls_section();
		// End Highlight Style Tab.

	}

	// Function For Adding Plan Sections.
	public function add_plan() {

		// Repeater For List.
		$repeater = new Repeater();

		// Switcher For Include | Exclude.
		$repeater->add_control(
			'epps_feature_icon_include_exclude', [
				'label' 			=> esc_html__('Feature Include | Exclude', EPPS_DOMAIN),
				'type' 				=> Controls_Manager::SWITCHER,
				'label_on' 			=> esc_html__('Include', EPPS_DOMAIN),
				'label_off' 		=> esc_html__('Exclude', EPPS_DOMAIN),
				'return_value' 		=> 'yes',
				'default' 			=> 'yes',
			]
		);

		// Feature Icon.
		$repeater->add_control(
			'epps_feature_icon', [
				'label'         	=> esc_html__('Feature Icon', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::ICONS,
				'default'       	=> [
					'value'     	=> 'fas fa-check',
					'library'   	=> 'fa-solid',
				],
			]
		);

		// Feature Content.
		$repeater->add_control(
			'epps_feature_text', [
				'label'         	=> esc_html__('Feature Content', EPPS_DOMAIN),
				'type'          	=> Controls_Manager::TEXTAREA,
				'default'       	=> esc_html__('Feature', EPPS_DOMAIN),
			]
		);

		// Start Column Content.
		for ( $i = 1; $i < 5; $i++ ) {

			// Plan Column Content.
			$this->start_controls_section(
				'epps_plan_section_' . $i, [
					'label'     	=> sprintf( esc_html__('Plan %s', EPPS_DOMAIN), $i ),
					'operator'  	=> '>',
					'condition' 	=> [
						'epps_plan_count' => $this->add_condition_value( $i ),
					],
				]
			);

			// Heading for 1st Value.
			$this->add_control(
				'epps_value_1_switcher_' . $i, [
					'label'        => esc_html__('Value 1', EPPS_DOMAIN),
					'type'         => Controls_Manager::HEADING,
					'description'  => esc_html__('For Switcher OFF Plan.', EPPS_DOMAIN),
				]
			);

			// For Switcher OFF Plan for 1st Value.
			$this->add_control(
				'epps_value_1_desc_' . $i, [
					'label' 		=> esc_html__('For Switcher OFF Plan.', EPPS_DOMAIN),
					'type' 			=> Controls_Manager::HEADING,
				]
			);

			// Title for 1st Value.
			$this->add_control(
				'epps_1_plan_title_' . $i, [
					'label'     	=> esc_html__('Title', EPPS_DOMAIN),
					'type'      	=> Controls_Manager::TEXT,
					'default'   	=> esc_html__('Title', EPPS_DOMAIN),
				]
			);

			// Title Tag for 1st Value.
			$this->add_control(
				'epps_1_plan_title_tag_' . $i, [
					'label'         => esc_html__('Title HTML Tag', EPPS_DOMAIN),
					'type'          => Controls_Manager::SELECT,
					'options'       => [
						'h1'        => 'H1',
						'h2'        => 'H2',
						'h3'        => 'H3',
						'h4'        => 'H4',
						'h5'        => 'H5',
						'h6'        => 'H6',
						'div'       => 'div',
						'span'      => 'span',
						'p'         => 'p',
					],
					'default'       => 'h2',
				]
			);

			// Title for 1st Value.
			$this->add_control(
				'epps_1_plan_price_' . $i, [
					'label'     	=> esc_html__('Price', EPPS_DOMAIN),
					'type'      	=> Controls_Manager::TEXT,
					'default'   	=> esc_html__('149', EPPS_DOMAIN),
				]
			);

			// Sale Price for 1st Value.
			$this->add_control(
				'epps_1_plan_sale_price_' . $i, [
					'label'     	=> esc_html__('Sale Price', EPPS_DOMAIN),
					'type'      	=> Controls_Manager::TEXT,
					'default'   	=> esc_html__('99', EPPS_DOMAIN),
				]
			);

			// Label Text for 1st Value.
			$this->add_control(
				'epps_1_plan_label_' . $i, [
					'label'     	=> esc_html__('Label', EPPS_DOMAIN),
					'type'      	=> Controls_Manager::TEXT,
				]
			);

			// Description for 1st Value.
			$this->add_control(
				'epps_1_plan_description_' . $i, [
					'label' 		=> esc_html__('Description', EPPS_DOMAIN),
					'type' 			=> Controls_Manager::TEXTAREA,
					'default'   	=> 'Lorem ipsum dolor, sit amet consectetur adipisicing elit. Incidunt, quas!',
				]
			);

			// Button Text for 1st Value.
			$this->add_control(
				'epps_1_button_text_' . $i, [
					'label'     	=> esc_html__('Button Text', EPPS_DOMAIN),
					'type'      	=> Controls_Manager::TEXT,
					'default'   	=> esc_html__('Buy Now', EPPS_DOMAIN),
				]
			);

			// Button Link for 1st Value.
			$this->add_control(
				'epps_1_plan_link_' . $i, [
					'label'       	=> esc_html__('Link', EPPS_DOMAIN),
					'type'        	=> Controls_Manager::URL,
					'placeholder' 	=> 'https://your-link.com',
					'default'     	=> [
						'url'         => '#',
						'is_external' => true,
						'nofollow'    => true,
					],
					'label_block' 	=> true,
				]
			);

			// Feature Title for 1st Value.
			$this->add_control(
				'epps_1_feature_title_' . $i, [
					'label'     	=> esc_html__('Feature Title', EPPS_DOMAIN),
					'type'      	=> Controls_Manager::TEXT,
					'default'   	=> esc_html__('Top Features', EPPS_DOMAIN),
				]
			);

			// Feature Title HTML Tag for 1st Value.
			$this->add_control(
				'epps_1_feature_title_tag_' . $i, [
					'label'         => esc_html__('Feature Title HTML Tag', EPPS_DOMAIN),
					'type'          => Controls_Manager::SELECT,
					'options'       => [
						'h1'        => 'H1',
						'h2'        => 'H2',
						'h3'        => 'H3',
						'h4'        => 'H4',
						'h5'        => 'H5',
						'h6'        => 'H6',
						'div'       => 'div',
						'span'      => 'span',
						'p'         => 'p',
					],
					'default'       => 'h4',
				]
			);

			// Feature List for 1st Value.
			$this->add_control(
				'epps_1_feature_list_' .$i, [
					'label'         => esc_html__('Feature List', EPPS_DOMAIN),
					'type'          => Controls_Manager::REPEATER,
					'fields'        => $repeater->get_controls(),
					'render_type'   => 'template',
					'default'       => [
						[
							'epps_feature_text' => esc_html__('Lorem ipsum dolor sit amet', EPPS_DOMAIN),
						],
						[
							'epps_feature_text' => esc_html__('Lorem ipsum dolor sit amet', EPPS_DOMAIN),
						],
						[
							'epps_feature_text' => esc_html__('Lorem ipsum dolor sit amet', EPPS_DOMAIN),
						],
						[
							'epps_feature_text' => esc_html__('Lorem ipsum dolor sit amet', EPPS_DOMAIN),
							'epps_feature_icon_include_exclude' => 'no',
							'epps_feature_icon' => ['value'=> 'fas fa-times','library' => 'fa-solid'],
						],
					],
				]
			);

			// Heading Text for 2nd Value.
			$this->add_control(
				'epps_value_2_switcher_' . $i, [
					'label'        => esc_html__('Value 2', EPPS_DOMAIN),
					'type'         => Controls_Manager::HEADING,
					'separator'    => 'before',
					'condition'    => [
						'epps_plan_switcher' => 'yes',
					],
				]
			);

			// For Switcher ON Plan Text for 2nd Value.
			$this->add_control(
				'epps_value_2_desc_' . $i, [
					'label' 		=> esc_html__('For Switcher ON Plan.', EPPS_DOMAIN),
					'type' 			=> Controls_Manager::HEADING,
					'condition'    	=> [
						'epps_plan_switcher' => 'yes',
					],
				]
			);

			// Title for 2nd Value.
			$this->add_control(
				'epps_2_plan_title_' . $i, [
					'label'     	=> esc_html__('Title', EPPS_DOMAIN),
					'type'      	=> Controls_Manager::TEXT,
					'default'   	=> esc_html__('Title', EPPS_DOMAIN),
					'condition' 	=> [
						'epps_plan_switcher' => 'yes',
					],
				]
			);

			// Title HTML Tag for 2nd Value.
			$this->add_control(
				'epps_2_plan_title_tag_' . $i, [
					'label'         => esc_html__('Title HTML Tag', EPPS_DOMAIN),
					'type'          => Controls_Manager::SELECT,
					'options'       => [
						'h1'        => 'H1',
						'h2'        => 'H2',
						'h3'        => 'H3',
						'h4'        => 'H4',
						'h5'        => 'H5',
						'h6'        => 'H6',
						'div'       => 'div',
						'span'      => 'span',
						'p'         => 'p',
					],
					'default'       => 'h2',
					'condition' 	=> [
						'epps_plan_switcher' => 'yes',
					],
				]
			);

			// Price for 2nd Value.
			$this->add_control(
				'epps_2_plan_price_' . $i, [
					'label'     	=> esc_html__('Price', EPPS_DOMAIN),
					'type'      	=> Controls_Manager::TEXT,
					'default'   	=> esc_html__('199', EPPS_DOMAIN),
					'condition' 	=> [
						'epps_plan_switcher' => 'yes',
					],
				]
			);

			// Sale Price for 2nd Value.
			$this->add_control(
				'epps_2_plan_sale_price_' . $i, [
					'label'     	=> esc_html__('Sale Price', EPPS_DOMAIN),
					'type'      	=> Controls_Manager::TEXT,
					'default'   	=> esc_html__('149', EPPS_DOMAIN),
					'condition' 	=> [
						'epps_plan_switcher' => 'yes',
					],
				]
			);

			// Label Text for 2nd Value.
			$this->add_control(
				'epps_2_plan_label_' . $i, [
					'label'     	=> esc_html__('Label', EPPS_DOMAIN),
					'type'      	=> Controls_Manager::TEXT,
					'condition' 	=> [
						'epps_plan_switcher' => 'yes',
					],
				]
			);

			// Description for 2nd Value.
			$this->add_control(
				'epps_2_plan_description_' . $i, [
					'label' 		=> esc_html__('Description', EPPS_DOMAIN),
					'type' 			=> Controls_Manager::TEXTAREA,
					'default'   	=> 'Lorem ipsum dolor, sit amet consectetur adipisicing elit. Incidunt, quas!',
					'condition' 	=> [
						'epps_plan_switcher' => 'yes',
					],
				]
			);

			// Button Text for 2nd Value.
			$this->add_control(
				'epps_2_button_text_' . $i, [
					'label'     	=> esc_html__('Button Text', EPPS_DOMAIN),
					'type'      	=> Controls_Manager::TEXT,
					'default'   	=> esc_html__('Buy Now', EPPS_DOMAIN),
					'condition' 	=> [
						'epps_plan_switcher' => 'yes',
					],
				]
			);

			// Button Link for 2nd Value.
			$this->add_control(
				'epps_2_plan_link_' . $i, [
					'label'       	=> esc_html__('Link', EPPS_DOMAIN),
					'type'        	=> Controls_Manager::URL,
					'placeholder' 	=> 'https://your-link.com',
					'default'     	=> [
						'url'         => '#',
						'is_external' => true,
						'nofollow'    => true,
					],
					'label_block' 	=> true,
					'condition'   	=> [
						'epps_plan_switcher' => 'yes',
					],
				]
			);

			// Feature Title for 2nd Value.
			$this->add_control(
				'epps_2_feature_title_' . $i, [
					'label'     	=> esc_html__('Feature Title', EPPS_DOMAIN),
					'type'      	=> Controls_Manager::TEXT,
					'default'   	=> esc_html__('Top Features', EPPS_DOMAIN),
					'condition' 	=> [
						'epps_plan_switcher' => 'yes',
					],
				]
			);

			// Feature Title HTML Tag for 2nd Value.
			$this->add_control(
				'epps_2_feature_title_tag_' . $i, [
					'label'         => esc_html__('Feature Title HTML Tag', EPPS_DOMAIN),
					'type'          => Controls_Manager::SELECT,
					'options'       => [
						'h1'        => 'H1',
						'h2'        => 'H2',
						'h3'        => 'H3',
						'h4'        => 'H4',
						'h5'        => 'H5',
						'h6'        => 'H6',
						'div'       => 'div',
						'span'      => 'span',
						'p'         => 'p',
					],
					'default'       => 'h4',
					'condition' 	=> [
						'epps_plan_switcher' => 'yes',
					],
				]
			);

			// Feature List for 2nd Value.
			$this->add_control(
				'epps_2_feature_list_' .$i, [
					'label'         => esc_html__('Feature List', EPPS_DOMAIN),
					'type'          => Controls_Manager::REPEATER,
					'fields'        => $repeater->get_controls(),
					'render_type'   => 'template',
					'default'       => [
						[
							'epps_feature_text' => esc_html__('Lorem ipsum dolor sit amet', EPPS_DOMAIN),
						],
						[
							'epps_feature_text' => esc_html__('Lorem ipsum dolor sit amet', EPPS_DOMAIN),
						],
						[
							'epps_feature_text' => esc_html__('Lorem ipsum dolor sit amet', EPPS_DOMAIN),
						],
						[
							'epps_feature_text' => esc_html__('Lorem ipsum dolor sit amet', EPPS_DOMAIN),
							'epps_feature_icon_include_exclude' => 'no',
							'epps_feature_icon' => ['value'=> 'fas fa-times','library'   => 'fa-solid'],
						],
					],
					'condition' => [
						'epps_plan_switcher' => 'yes',
					],
				]
			);

			// Switcher for Override Style.
			$this->add_control(
				'epps_override_style_' . $i, [
					'label'        => esc_html__('Override Style', EPPS_DOMAIN),
					'type'         => Controls_Manager::SWITCHER,
					'return_value' => 'yes',
					'default'      => 'no',
					'separator'    => 'before',
				]
			);

			// Plan.
			$this->add_control(
				'epps_or_plan_' . $i, [
					'label'     	=> esc_html__('Plan', EPPS_DOMAIN),
					'type'      	=> Controls_Manager::HEADING,
					'condition' 	=> [
						'epps_override_style_' . $i => 'yes',
					],
				]
			);

			// Plan Gradient Background.
			$this->add_group_control(
				Group_Control_Background::get_type(), [
					'name'          	=> 'epps_or_bg_color' . $i,
					'types'        		=> ['classic', 'gradient'],
					'selector'      	=> '{{WRAPPER}} .epps-main-wrapper .epps-plan-list .epps-plan-'. ($i-1) . ' .epps-plan',
					'fields_options'    => [
						'background'    => [
							'label'     => esc_html__('Background Color', EPPS_DOMAIN),
						],
					],
					'condition' 	=> [
						'epps_override_style_' . $i => 'yes',
					],
				]
			);

			// Border Color.
			$this->add_control(
				'ct_or_border_color_' . $i, [
					'label'     	=> esc_html__('Border Color', EPPS_DOMAIN),
					'type'      	=> Controls_Manager::COLOR,
					'selectors' 	=> [
						'{{WRAPPER}} .epps-main-wrapper .epps-plan-list .epps-plan-'. ($i-1) . ' .epps-plan'=> 'border-color: {{VALUE}};'
					],
					'condition' 	=> [
						'epps_override_style_' . $i => 'yes',
					],
				]
			);

			// Title.
			$this->add_control(
				'epps_or_heading_' . $i, [
					'label'     	=> esc_html__('Title', EPPS_DOMAIN),
					'type'      	=> Controls_Manager::HEADING,
					'condition' 	=> [
						'epps_override_style_' . $i => 'yes',
					],
				]
			);

			// Color for Title.
			$this->add_control(
				'ct_heading_or_color_' . $i, [
					'label'     	=> esc_html__('Title Color', EPPS_DOMAIN),
					'type'      	=> Controls_Manager::COLOR,
					'selectors' 	=> [
						'{{WRAPPER}} .epps-main-wrapper .epps-plan-'. ($i-1) .' .epps-plan-heading'=> 'color: {{VALUE}};'
					],
					'condition' 	=> [
						'epps_override_style_' . $i => 'yes',
					],
				]
			);

			// Title Gradient Background.
			$this->add_group_control(
				Group_Control_Background::get_type(), [
					'name'          	=> 'epps_title_bg_or_color_'. $i,
					'selector'     		=> '{{WRAPPER}} .epps-design-1 .epps-plan-'. ($i-1) .' .epps-title-price-wrapper,
					{{WRAPPER}} .epps-design-2 .epps-plan-'. ($i-1) .' .epps-heading-wrapper,
					{{WRAPPER}} .epps-design-3 .epps-plan-'. ($i-1) .' .epps-heading-wrapper,
					{{WRAPPER}} .epps-design-3 .epps-plan-'. ($i-1) .' .epps-heading-wrapper:before,
					{{WRAPPER}} .epps-design-4 .epps-plan-'. ($i-1) .' .epps-title-price-wrapper,
					{{WRAPPER}} .epps-design-5 .epps-plan-'. ($i-1) .' .epps-heading-wrapper',
					'types'         	=> ['classic', 'gradient'],
					'fields_options'    => [
						'background'    => [
							'label'     => esc_html__('Title Background Color', EPPS_DOMAIN),
						],
					],
					'condition' 	=> [
						'epps_override_style_' . $i => 'yes',
					],
				]
			);

			// Price.
			$this->add_control(
				'epps_or_price_' . $i, [
					'label'     	=> esc_html__('Price', EPPS_DOMAIN),
					'type'      	=> Controls_Manager::HEADING,
					'condition' 	=> [
						'epps_override_style_' . $i => 'yes',
					],
				]
			);

			// Price Color.
			$this->add_control(
				'epps_or_price_color_' . $i, [
					'label'         	=> esc_html__('Color', EPPS_DOMAIN),
					'type'          	=> Controls_Manager::COLOR,
					'selectors'     	=> [
						'{{WRAPPER}} .epps-main-wrapper .epps-plan-'. ($i-1) .' .epps-normal-price' => 'color: {{VALUE}};',
					],
					'condition' 	=> [
						'epps_override_style_' . $i => 'yes',
					],
				]
			);

			// Price Color.
			$this->add_control(
				'epps_line_or_color'. $i, [
					'label'         	=> esc_html__('Price Line Through', EPPS_DOMAIN),
					'type'          	=> Controls_Manager::COLOR,
					'selectors'     	=> [
						'{{WRAPPER}} .epps-main-wrapper .epps-plan-'. ($i-1) .' .epps-price-line p' => 'text-decoration-color: {{VALUE}};',
					],
					'condition'			=> [
						'epps_price_line_through' 	=> 'yes',
						'epps_override_style_' . $i => 'yes',
					],
				]
			);

			// Sale Price Color.
			$this->add_control(
				'epps_or_sale_color_'. $i, [
					'label'         	=> esc_html__('Sale Price Color', EPPS_DOMAIN),
					'type'          	=> Controls_Manager::COLOR,
					'selectors'     	=> [
						'{{WRAPPER}} .epps-main-wrapper .epps-plan-'. ($i-1) .' .epps-sale-price' => 'color: {{VALUE}};',
					],
					'condition' 	=> [
						'epps_override_style_' . $i => 'yes',
					],
				]
			);

			// Description.
			$this->add_control(
				'epps_or_desc_' . $i, [
					'label'     	=> esc_html__('Description', EPPS_DOMAIN),
					'type'      	=> Controls_Manager::HEADING,
					'condition' 	=> [
						'epps_override_style_' . $i => 'yes',
					],
				]
			);

			// Description Color.
			$this->add_control(
				'epps_or_desc_color_' . $i, [
					'label'         	=> esc_html__('Color', EPPS_DOMAIN),
					'type'          	=> Controls_Manager::COLOR,
					'selectors'     	=> [
						'{{WRAPPER}} .epps-main-wrapper .epps-plan-'. ($i-1) .' .epps-plan-description' => 'color: {{VALUE}};',
					],
					'condition' 	=> [
						'epps_override_style_' . $i => 'yes',
					],
				]
			);

			// Feature Title.
			$this->add_control(
				'epps_or_feat_title_' . $i, [
					'label'     	=> esc_html__('Feature Title', EPPS_DOMAIN),
					'type'      	=> Controls_Manager::HEADING,
					'condition' 	=> [
						'epps_override_style_' . $i => 'yes',
					],
				]
			);

			// Feature Title.
			$this->add_control(
				'epps_or_feat_title_color_' . $i, [
					'label'         	=> esc_html__('Color', EPPS_DOMAIN),
					'type'          	=> Controls_Manager::COLOR,
					'selectors'     	=> [
						'{{WRAPPER}} .epps-main-wrapper .epps-plan-'. ($i-1) .' .epps-plan-features-title' => 'color: {{VALUE}};',
					],
					'condition' 	=> [
						'epps_override_style_' . $i => 'yes',
					],
				]
			);

			// Feature List.
			$this->add_control(
				'epps_or_feat_list_' . $i, [
					'label'     	=> esc_html__('Feature List', EPPS_DOMAIN),
					'type'      	=> Controls_Manager::HEADING,
					'condition' 	=> [
						'epps_override_style_' . $i => 'yes',
					],
				]
			);

			// Include Icon Color.
			$this->add_control(
				'epps_or_feat_incl_icon_' . $i, [
					'label'         	=> esc_html__('Include Icon Color', EPPS_DOMAIN),
					'type'          	=> Controls_Manager::COLOR,
					'selectors'     	=> [
						'{{WRAPPER}} .epps-main-wrapper .epps-plan-'. ($i-1) .' i.epps-icon-include' => 'color: {{VALUE}};',
					],
					'condition' 	=> [
						'epps_override_style_' . $i => 'yes',
					],
				]
			);

			// Include List Color.
			$this->add_control(
				'epps_or_feat_incl_list_' . $i, [
					'label'         	=> esc_html__('Include List Color', EPPS_DOMAIN),
					'type'          	=> Controls_Manager::COLOR,
					'selectors'     	=> [
						'{{WRAPPER}} .epps-main-wrapper .epps-plan-'. ($i-1) .' .epps-feature-text.epps-icon-include' => 'color: {{VALUE}};',
					],
					'condition' 	=> [
						'epps_override_style_' . $i => 'yes',
					],
				]
			);

			// Exclude Icon Color.
			$this->add_control(
				'epps_or_feat_excl_icon_' . $i, [
					'label'         	=> esc_html__('Exclude Icon Color', EPPS_DOMAIN),
					'type'          	=> Controls_Manager::COLOR,
					'selectors'     	=> [
						'{{WRAPPER}} .epps-main-wrapper .epps-plan-'. ($i-1) .' i.epps-icon-exclude' => 'color: {{VALUE}};',
					],
					'condition' 	=> [
						'epps_override_style_' . $i => 'yes',
					],
				]
			);

			// Exclude List Color.
			$this->add_control(
				'epps_or_feat_excl_list_' . $i, [
					'label'         	=> esc_html__('Exclude List Color', EPPS_DOMAIN),
					'type'          	=> Controls_Manager::COLOR,
					'selectors'     	=> [
						'{{WRAPPER}} .epps-main-wrapper .epps-plan-'. ($i-1) .' .epps-feature-text.epps-icon-exclude' => 'color: {{VALUE}};',
					],
					'condition' 	=> [
						'epps_override_style_' . $i => 'yes',
					],
				]
			);

			// Button.
			$this->add_control(
				'epps_or_button_' . $i, [
					'label'     	=> esc_html__('Button', EPPS_DOMAIN),
					'type'      	=> Controls_Manager::HEADING,
					'condition' 	=> [
						'epps_override_style_' . $i => 'yes',
					],
				]
			);

			// Text Color.
			$this->add_control(
				'epps_or_btn_text_' . $i, [
					'label'         	=> esc_html__('Text Color', EPPS_DOMAIN),
					'type'          	=> Controls_Manager::COLOR,
					'selectors'     	=> [
						'{{WRAPPER}} .epps-main-wrapper .epps-plan-'. ($i-1) .' .epps-plan-btn' => 'color: {{VALUE}};',
					],
					'condition' 	=> [
						'epps_override_style_' . $i => 'yes',
					],
				]
			);

			// Button Gradient Background.
			$this->add_group_control(
				Group_Control_Background::get_type(), [
					'name'          	=> 'epps_or_btn_bg_'. $i,
					'selector'     		=> '{{WRAPPER}} .epps-main-wrapper .epps-plan-'. ($i-1) .' .epps-plan-btn',
					'types'         	=> ['classic', 'gradient'],
					'fields_options'    => [
						'background'    => [
							'label'     => esc_html__('Background Color', EPPS_DOMAIN),
						],
					],
					'condition' 	=> [
						'epps_override_style_' . $i => 'yes',
					],
				]
			);

			// Text Color.
			$this->add_control(
				'epps_or_btn_border_' . $i, [
					'label'         	=> esc_html__('Border Color', EPPS_DOMAIN),
					'type'          	=> Controls_Manager::COLOR,
					'selectors'     	=> [
						'{{WRAPPER}} .epps-main-wrapper .epps-plan-'. ($i-1) .' .epps-plan-btn' => 'border-color: {{VALUE}};',
					],
					'condition' 	=> [
						'epps_override_style_' . $i => 'yes',
					],
				]
			);

			// Button Hover Color.
			$this->add_control(
				'epps_or_btn_hover_' . $i, [
					'label'     	=> esc_html__('Button Hover Color', EPPS_DOMAIN),
					'type'      	=> Controls_Manager::HEADING,
					'condition' 	=> [
						'epps_override_style_' . $i => 'yes',
					],
				]
			);

			// Text Color.
			$this->add_control(
				'epps_or_btn_txt_' . $i, [
					'label'         	=> esc_html__('Text Color', EPPS_DOMAIN),
					'type'          	=> Controls_Manager::COLOR,
					'selectors'     	=> [
						'{{WRAPPER}} .epps-main-wrapper .epps-plan-'. ($i-1) .' .epps-plan-btn:hover' => 'color: {{VALUE}};',
					],
					'condition' 	=> [
						'epps_override_style_' . $i => 'yes',
					],
				]
			);

			// Button Gradient Background.
			$this->add_group_control(
				Group_Control_Background::get_type(), [
					'name'          	=> 'epps_or_bg_btn_'. $i,
					'selector'     		=> '{{WRAPPER}} .epps-main-wrapper .epps-plan-'. ($i-1) .' .epps-plan-btn:hover',
					'types'         	=> ['classic', 'gradient'],
					'fields_options'    => [
						'background'    => [
							'label'     => esc_html__('Background Color', EPPS_DOMAIN),
						],
					],
					'condition' 	=> [
						'epps_override_style_' . $i => 'yes',
					],
				]
			);

			// Text Color.
			$this->add_control(
				'epps_or_btn_bdr_' . $i, [
					'label'         	=> esc_html__('Border Color', EPPS_DOMAIN),
					'type'          	=> Controls_Manager::COLOR,
					'selectors'     	=> [
						'{{WRAPPER}} .epps-main-wrapper .epps-plan-'. ($i-1) .' .epps-plan-btn:hover' => 'border-color: {{VALUE}};',
					],
					'condition' 	=> [
						'epps_override_style_' . $i => 'yes',
					],
				]
			);

			// Label.
			$this->add_control(
				'epps_or_label_' . $i, [
					'label'     	=> esc_html__('Label', EPPS_DOMAIN),
					'type'      	=> Controls_Manager::HEADING,
					'condition' 	=> [
						'epps_override_style_' . $i => 'yes',
					],
				]
			);

			// Label Color.
			$this->add_control(
				'epps_or_label_txt_' . $i, [
					'label'         	=> esc_html__('Color', EPPS_DOMAIN),
					'type'          	=> Controls_Manager::COLOR,
					'selectors'     	=> [
						'{{WRAPPER}} .epps-main-wrapper .epps-plan-'. ($i-1) .' .epps-plan-label' => 'color: {{VALUE}};',
					],
					'condition' 	=> [
						'epps_override_style_' . $i => 'yes',
					],
				]
			);

			// Label Background Color.
			$this->add_control(
				'epps_or_label_bg_' . $i, [
					'label'         	=> esc_html__('Background Color', EPPS_DOMAIN),
					'type'          	=> Controls_Manager::COLOR,
					'selectors'     	=> [
						'{{WRAPPER}} .epps-main-wrapper .epps-plan-'. ($i-1) .' .epps-plan-label' => 'background-color: {{VALUE}};',
					],
					'condition' 	=> [
						'epps_override_style_' . $i => 'yes',
					],
				]
			);

			$this->end_controls_section();
		}
	}

	// Function For Counting Plans.
	public function add_condition_value( $j ) {
		$value = [];
		for ( $i = $j; $i < 5; $i++ ) {
			$value[] = $i;
		}
		return $value;
	}

	/**
	 * Render Essential Pricing Plan Switcher for Elementor widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @access protected
	 */
	protected function render(){
		$settings = $this->get_settings_for_display();
		switch($settings['epps_design']){
			case 'design-1':
				include EPPS_PATH . 'include/essential-pricing-plan-switcher/design-1.php'; // Pricing Plan Design 1.
				break;
			case 'design-2':
				include EPPS_PATH . 'include/essential-pricing-plan-switcher/design-2.php'; // Pricing Plan Design 2.
				break;
			case 'design-3':
				include EPPS_PATH . 'include/essential-pricing-plan-switcher/design-3.php'; // Pricing Plan Design 3.
				break;
			case 'design-4':
				include EPPS_PATH . 'include/essential-pricing-plan-switcher/design-4.php'; // Pricing Plan Design 4.
				break;
			case 'design-5':
				include EPPS_PATH . 'include/essential-pricing-plan-switcher/design-5.php'; // Pricing Plan Design 5.
				break;
			default:
				include EPPS_PATH . 'include/essential-pricing-plan-switcher/design-1.php'; // Pricing Plan Design 1.
				break;
		}
	}
}
plugin::instance()->widgets_manager->register(new EPPS_Widget());
?>